#
# spec file for package croc
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2021 Orville Q. Song <orville@anislet.dev>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global provider        github
%global provider_tld    com
%global project         schollz
%global repo            croc
%global provider_prefix %{provider}.%{provider_tld}/%{project}
%global import_path     %{provider_prefix}/%{repo}

Name:           croc
Version:        9.6.5
Release:        bp156.1.14
Summary:        Easily and securely send things from one computer to another
License:        MIT
Group:          Networking/File transfer
URL:            https://github.com/schollz/croc
Source0:        %{name}-%{version}.tar.xz
Source1:        vendor.tar.xz
Source2:        %{name}.service
BuildRequires:  golang-packaging
BuildRequires:  golang(API) >= 1.20

%{go_nostrip}
%{go_provides}

%description
croc could easily and securely send things from one computer to another.

%prep
%setup -q -n %{name}-%{version}
%setup -a1 %{SOURCE1}

%build
%goprep .
mkdir -p vendor/%{provider_prefix}
ln -s . vendor/%{import_path}
%gobuild -ldflags "-s -w" .

%install
%goinstall
install -D -m 644 %{SOURCE2} %{buildroot}%{_unitdir}/%{name}.service

%pre
%service_add_pre %{name}.service

%post
%service_add_post %{name}.service

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%files
%defattr(-,root,root)
%license LICENSE
%doc README.md
%{_bindir}/%{name}
%{_unitdir}/%{name}.service

%changelog
* Thu Jul  6 2023 Joshua Smith <jsmithfpv@gmail.com>
- Update to version 9.6.5:
  * update deps
  * croc.service: use DynamicUser
  * upgrade dependencies
  * Update: update error messages for http proxy
  * Feat: support http proxy as a complementary way to use in
    network limited environments.
  * Fix some typos
  * localhost -> 127.0.0.1 Fixes #513
  * Bump actions/setup-go from 2 to 4
  * Enhance tab completion
  * Bump docker/setup-buildx-action from 1 to 2
  * add dependabot
  * add Winget installation instructions
  * add winget releaser workflow
* Tue Jun  6 2023 Joshua Smith <jsmithfpv@gmail.com>
- Update to version 9.6.4:
  * bump 9.6.4
  * Upgrade Go version to 1.20 and dependencies to latest
  * Update CI to run on main branch events
  * Chmod new file based on the source file mode
  * Small optimization + consistent variable names style
  * Implement tab completion for words
  * path -> fpath
  * run through gofumpt
  * Typo fix
  * revert back to flate instead of zstd
  * Replaced zstd package
  * Added zstd as a compression algorithm
  * addresses #496 gettings ports doing LAN
  * println -> print os.stderr
  * remove zip compression and add --zip to send command
  * Fixed relative path / bug
  * Added support for sending relative folder
  * Unzipping file at the reciever end
  * Added UnzipDirectory function
  * Modified the argument for GetFilesInfo in tests
  * Handling the --zip flag
  * Added --zip CLI argument for zipping all the dir specified
  * added ZipDirectory function
  * don't show number of folders if the number is 0
  * update ui
  * Fix relay IPv4 address resolution behind DNS64
  * add Fedora instructions to README
  * avoid deadlock
  * new support system
  * #463 fixed display at receiving end
  * #463 fixed croc tests for empty folders, and to work in
    Windows
  * #463 fixed display for empty folders
  * #463 added capability to send/receive empty folders
  * update default curve
  * default to P-256
  * update readme
  * Drop shebang for bash completion
  * tcp: send error on fail
  * fix ui when sending text
  * #431 fixed remote folder name for Windows
  * #431 Integrate GetFilesInfo function with the code
  * #431 added file informations retrival functions to replace
    getPaths
  * #454 fixed local transfer
  * fix sending file with prefix "croc-stdin" renaming on
    receiver end
  * allow remembering --internal-dns flag
  * fix hash file error
* Sun Dec  5 2021 orville@anislet.dev
- Update to version 9.5.0:
  * bump 9.5.0
  * Fix Typos (revised)
  * fix ports for tests
  * update deps
  * refactor: move from io/ioutil to io and os packages
  * build: upgrade to Go 1.17
  * Fixed an error
* Fri Dec  3 2021 Orville Q. Song <orville@anislet.dev>
- Init croc Package.
  croc could help you easily and securely send things from one computer to another.
  Current Release: v9.5.0
  Commit Hash: 7390e7ed45bbf4037fa5e7e6d3545e0813b3529d
